@@ -5,29 +5,31 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 import copy
-import unittest
-from jinja2 import Template, TemplateSyntaxError
+
+from unittest import TestCase
+
 from ansible.playbook.task import Task
 from ansible.template import Templar
+from jinja2 import Template, TemplateSyntaxError
+
+from ansible_collections.ansible.utils.plugins.action.update_fact import ActionModule
 
-from ansible_collections.ansible.utils.plugins.action.update_fact import (
-    ActionModule,
-)
 
 try:
     from unittest.mock import MagicMock  # pylint:disable=syntax-error
 except ImportError:
-    from mock import MagicMock
+    from mock import MagicMock  # pyright: ignore[reportMissingModuleSource]
 
 
 VALID_DATA = {
     "a": {
         "b": {"4.4": [{"1": {5: {"foo": 123}}}], 5.5: "float5.5"},
         "127.0.0.1": "localhost",
-    }
+    },
 }
 
 VALID_TESTS = [
@@ -78,10 +80,13 @@ INVALID_JINJA = [
 ]
 
 
-class TestUpdate_Fact(unittest.TestCase):
+class TestUpdate_Fact(TestCase):
     def setUp(self):
         task = MagicMock(Task)
+        # Ansible > 2.13 looks for check_mode in task
+        task.check_mode = False
         play_context = MagicMock()
+        # Ansible <= 2.13 looks for check_mode in play_context
         play_context.check_mode = False
         connection = MagicMock()
         fake_loader = {}
@@ -101,18 +106,14 @@ class TestUpdate_Fact(unittest.TestCase):
         self._plugin._task.args = {"a": 10}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars=None)
-        self.assertIn(
-            "missing required arguments: updates", str(error.exception)
-        )
+        self.assertIn("missing required arguments: updates", str(error.exception))
 
     def test_argspec_none(self):
         """Check passing a dict"""
         self._plugin._task.args = {}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars=None)
-        self.assertIn(
-            "missing required arguments: updates", str(error.exception)
-        )
+        self.assertIn("missing required arguments: updates", str(error.exception))
 
     def test_valid_jinja(self):
         for test in VALID_TESTS:
@@ -137,9 +138,7 @@ class TestUpdate_Fact(unittest.TestCase):
         self._plugin._task.args = {"updates": [{"path": "a.b.c", "value": 5}]}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars={"vars": {}})
-        self.assertIn(
-            "'a' was not found in the current facts.", str(error.exception)
-        )
+        self.assertIn("'a' was not found in the current facts.", str(error.exception))
 
     def test_run_simple(self):
         """Confirm a valid argspec passes"""
@@ -153,9 +152,7 @@ class TestUpdate_Fact(unittest.TestCase):
 
     def test_run_multiple(self):
         """Confirm multiple paths passes"""
-        task_vars = {
-            "vars": {"a": {"b1": [1, 2, 3], "b2": {"c": "123", "d": False}}}
-        }
+        task_vars = {"vars": {"a": {"b1": [1, 2, 3], "b2": {"c": "123", "d": False}}}}
         expected = {"a": {"b1": [1, 2, 3, 4], "b2": {"c": 456, "d": True}}}
         expected.update({"changed": True})
         self._plugin._task.args = {
@@ -163,7 +160,7 @@ class TestUpdate_Fact(unittest.TestCase):
                 {"path": "a.b1.3", "value": 4},
                 {"path": "a.b2.c", "value": 456},
                 {"path": "a.b2.d", "value": True},
-            ]
+            ],
         }
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
@@ -194,9 +191,7 @@ class TestUpdate_Fact(unittest.TestCase):
         expected = copy.deepcopy(task_vars["vars"])
         expected["a"]["b"].append(4)
         expected.update({"changed": True})
-        self._plugin._task.args = {
-            "updates": [{"path": "a['b'][3]", "value": 4}]
-        }
+        self._plugin._task.args = {"updates": [{"path": "a['b'][3]", "value": 4}]}
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
 
@@ -206,9 +201,7 @@ class TestUpdate_Fact(unittest.TestCase):
         expected = copy.deepcopy(task_vars["vars"])
         expected["a"]["b"].append(4)
         expected.update({"changed": True})
-        self._plugin._task.args = {
-            "updates": [{"path": 'a["b"][3]', "value": 4}]
-        }
+        self._plugin._task.args = {"updates": [{"path": 'a["b"][3]', "value": 4}]}
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
 
@@ -228,9 +221,7 @@ class TestUpdate_Fact(unittest.TestCase):
         expected = copy.deepcopy(task_vars["vars"])
         expected["a"]["0"][0] = 0
         expected.update({"changed": True})
-        self._plugin._task.args = {
-            "updates": [{"path": 'a["0"].0', "value": 0}]
-        }
+        self._plugin._task.args = {"updates": [{"path": 'a["0"].0', "value": 0}]}
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
 
@@ -243,9 +234,7 @@ class TestUpdate_Fact(unittest.TestCase):
 
     def test_run_invalid_path_bracket_after_dot(self):
         """Invalid path format"""
-        self._plugin._task.args = {
-            "updates": [{"path": "a.['b']", "value": 0}]
-        }
+        self._plugin._task.args = {"updates": [{"path": "a.['b']", "value": 0}]}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars={"vars": {}})
         self.assertIn("malformed", str(error.exception))
@@ -273,9 +262,7 @@ class TestUpdate_Fact(unittest.TestCase):
         expected = copy.deepcopy(task_vars["vars"])
         expected["a"]["b"] = [1, 2, 3]
         expected.update({"changed": False})
-        self._plugin._task.args = {
-            "updates": [{"path": "a.b", "value": [1, 2, 3]}]
-        }
+        self._plugin._task.args = {"updates": [{"path": "a.b", "value": [1, 2, 3]}]}
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
 
@@ -290,14 +277,10 @@ class TestUpdate_Fact(unittest.TestCase):
     def test_run_list_not_int(self):
         """Confirm error when key not found"""
         task_vars = {"vars": {"a": {"b": [1]}}}
-        self._plugin._task.args = {
-            "updates": [{"path": "a.b['0']", "value": 2}]
-        }
+        self._plugin._task.args = {"updates": [{"path": "a.b['0']", "value": 2}]}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars=task_vars)
-        self.assertIn(
-            "index provided was not an integer", str(error.exception)
-        )
+        self.assertIn("index provided was not an integer", str(error.exception))
 
     def test_run_list_not_long(self):
         """List not long enough"""
@@ -305,9 +288,7 @@ class TestUpdate_Fact(unittest.TestCase):
         self._plugin._task.args = {"updates": [{"path": "a.b.2", "value": 2}]}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars=task_vars)
-        self.assertIn(
-            "not long enough for item #2 to be set", str(error.exception)
-        )
+        self.assertIn("not long enough for item #2 to be set", str(error.exception))
 
     def test_not_mutable_sequence_or_mapping(self):
         """Confirm graceful fail when immutable object
@@ -346,9 +327,7 @@ class TestUpdate_Fact(unittest.TestCase):
         self._plugin._task.args = {"updates": [{"path": "123", "value": 1}]}
         with self.assertRaises(Exception) as error:
             self._plugin.run(task_vars=task_vars)
-        self.assertIn(
-            "'123' was not found in the current facts", str(error.exception)
-        )
+        self.assertIn("'123' was not found in the current facts", str(error.exception))
 
     def test_run_not_dotted_success_same(self):
         """Test with a not dotted key, no change"""
@@ -365,8 +344,6 @@ class TestUpdate_Fact(unittest.TestCase):
         expected = copy.deepcopy(task_vars["vars"])
         expected["a"]["True"] = 1
         expected.update({"changed": True})
-        self._plugin._task.args = {
-            "updates": [{"path": "a['True']", "value": 1}]
-        }
+        self._plugin._task.args = {"updates": [{"path": "a['True']", "value": 1}]}
         result = self._plugin.run(task_vars=task_vars)
         self.assertEqual(result, expected)
