@@ -14,11 +14,6 @@ __metaclass__ = type
 
 from unittest import TestCase
 
-import pytest
-
-from ansible.errors import AnsibleFilterError
-from ansible.template import AnsibleUndefined
-
 from ansible_collections.ansible.utils.plugins.filter.ipv6 import _ipv6
 
 
@@ -48,15 +43,6 @@ class TestIp6(TestCase):
     def setUp(self):
         pass
 
-    def test_ipv6_undefined_value(self):
-        """Check ipv6 filter undefined value"""
-        args = ["", AnsibleUndefined(name="my_ip"), ""]
-        with pytest.raises(
-            AnsibleFilterError,
-            match="Unrecognized type <<class 'ansible.template.AnsibleUndefined'>> for ipv6 filter <value>",
-        ):
-            _ipv6(*args)
-
     def test_ipv6_filter_empty_query(self):
         """Check ipv6 filter empty query"""
         args = ["", VALID_DATA, ""]
