@@ -6,12 +6,10 @@
 # Make coding more python3-ish
 from __future__ import absolute_import, division, print_function
 
-
 __metaclass__ = type
 
 
 import pytest
-from ansible_collections.community.dns.plugins.modules import wait_for_txt
 from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import (
     MagicMock,
     patch,
@@ -23,6 +21,8 @@ from ansible_collections.community.internal_test_tools.tests.unit.plugins.module
     set_module_args,
 )
 
+from ansible_collections.community.dns.plugins.modules import wait_for_txt
+
 from ..module_utils.resolver_helper import (
     create_mock_answer,
     create_mock_response,
@@ -30,7 +30,6 @@ from ..module_utils.resolver_helper import (
     mock_resolver,
 )
 
-
 # We need dnspython
 dns = pytest.importorskip('dns')
 
@@ -216,6 +215,10 @@ class TestWaitForTXT(ModuleTestCase):
             'ns.example.com': ['asdf'],
             'ns.example.org': ['asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf'],
+            'ns.example.org': ['asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 1
 
     def test_double(self):
@@ -354,7 +357,7 @@ class TestWaitForTXT(ModuleTestCase):
                                     },
                                     {
                                         'name': 'mail.example.com',
-                                        'values': [
+                                        'entries': [
                                             'foo bar',
                                             'any bar',
                                         ],
@@ -374,12 +377,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': ['any bar'],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': ['any bar'],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_subset(self):
@@ -498,6 +507,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['foo bar', 'another one', 'asdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['foo bar', 'another one', 'asdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
 
     def test_superset(self):
@@ -626,7 +638,7 @@ class TestWaitForTXT(ModuleTestCase):
                                 'records': [
                                     {
                                         'name': 'www.example.com',
-                                        'values': [
+                                        'entries': [
                                             'asdf',
                                             'bee',
                                         ],
@@ -653,12 +665,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdf', 'bee'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdf', 'bee'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': [],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': [],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_superset_not_empty(self):
@@ -762,7 +780,7 @@ class TestWaitForTXT(ModuleTestCase):
                                 'records': [
                                     {
                                         'name': 'example.com',
-                                        'values': [
+                                        'entries': [
                                             'bumble',
                                             'bee',
                                         ],
@@ -781,6 +799,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['bumble', 'bee'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['bumble', 'bee'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals(self):
@@ -904,6 +925,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['bumble bee', 'wizard', 'foo'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['bumble bee', 'wizard', 'foo'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_equals_ordered(self):
@@ -1028,6 +1052,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['foo', 'bumble bee', 'wizard'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['foo', 'bumble bee', 'wizard'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 4
 
     def test_timeout(self):
@@ -1188,12 +1215,18 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['values'] == {
             'ns.example.com': ['asdfasdf'],
         }
+        assert exc.value.args[0]['records'][0]['entries'] == {
+            'ns.example.com': ['asdfasdf'],
+        }
         assert exc.value.args[0]['records'][0]['check_count'] == 3
         assert exc.value.args[0]['records'][1]['name'] == 'mail.example.com'
         assert exc.value.args[0]['records'][1]['done'] is True
         assert exc.value.args[0]['records'][1]['values'] == {
             'ns.example.com': ['any bar'],
         }
+        assert exc.value.args[0]['records'][1]['entries'] == {
+            'ns.example.com': ['any bar'],
+        }
         assert exc.value.args[0]['records'][1]['check_count'] == 1
 
     def test_nxdomain(self):
@@ -1296,7 +1329,9 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert len(exc.value.args[0]['records'][0]['values']) == 1
+        assert len(exc.value.args[0]['records'][0]['entries']) == 1
         assert exc.value.args[0]['records'][0]['values']['ns.example.com'] == []
+        assert exc.value.args[0]['records'][0]['entries']['ns.example.com'] == []
         assert exc.value.args[0]['records'][0]['check_count'] == 2
 
     def test_servfail(self):
@@ -1336,6 +1371,7 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert 'values' not in exc.value.args[0]['records'][0]
+        assert 'entries' not in exc.value.args[0]['records'][0]
         assert exc.value.args[0]['records'][0]['check_count'] == 0
 
     def test_cname_loop(self):
@@ -1476,4 +1512,5 @@ class TestWaitForTXT(ModuleTestCase):
         assert exc.value.args[0]['records'][0]['name'] == 'www.example.com'
         assert exc.value.args[0]['records'][0]['done'] is False
         assert 'values' not in exc.value.args[0]['records'][0]
+        assert 'entries' not in exc.value.args[0]['records'][0]
         assert exc.value.args[0]['records'][0]['check_count'] == 0
