@@ -19,8 +19,8 @@ def main():
     sys.stdout.reconfigure(errors="surrogateescape")
 
     for line in sys.stdin:
-        seconds = time.time() - start
-        sys.stdout.write("%02d:%02d %s" % (seconds // 60, seconds % 60, line))
+        seconds = int(time.time() - start)
+        sys.stdout.write(f"{seconds // 60:02}:{seconds % 60:02} {line}")
         sys.stdout.flush()
 
 
