@@ -266,9 +266,9 @@ class NetAppCloudManagerConnectorAzure(object):
             proxy_certificates=dict(required=False, type='list', elements='str'),
             associate_public_ip_address=dict(required=False, type='bool', default=True),
             account_id=dict(required=True, type='str'),
-            proxy_url=dict(required=False, type='str', default=''),
-            proxy_user_name=dict(required=False, type='str', default=''),
-            proxy_password=dict(required=False, type='str', default='', no_log=True),
+            proxy_url=dict(required=False, type='str'),
+            proxy_user_name=dict(required=False, type='str'),
+            proxy_password=dict(required=False, type='str', no_log=True),
             admin_username=dict(required=True, type='str'),
             admin_password=dict(required=True, type='str', no_log=True),
             storage_account=dict(required=False, type='str'),
